export const FormColumns = [
  {
    key: "priceName",
    title: "价格名称",
    inputType: "Input",
    value: "价格申报单",
  },
  {
    key: "supplierName",
    title: "供应商",
    inputType: "PopoverSelect",
    referName: "SUPPLIER_PARAM",
    valueKey: "name",
    dataMapping: {
      supplier: "id",
      supplierCode: "code",
      supplierName: "name",
    },
    require: true,
  },
  {
    key: "supplierCode",
    title: "供应商编码",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "puOrgName",
    title: "采购组织",
    inputType: "PopoverSelect",
    referName: "ORG_PARAM",
    valueKey: "name",
    dataMapping: {
      puOrg: "id",
      puOrgCode: "code",
      puOrgName: "name",
    },
    require: true,
  },
  {
    key: "puOrgCode",
    title: "采购组织编码",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "currencyName",
    title: "币种",
    inputType: "PopoverSelect",
    referName: "CURRENCY_PARAM",
    dataMapping: {
      currency: "id",
      currencyCode: "code",
      currencyName: "name",
    },
    require: true,
  },
  {
    key: "currencyCode",
    title: "币种编码",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "explainStr",
    title: "价格合理性说明",
    inputType: "Input",
    require: true,
  },
  {
    key: "buyerName",
    title: "采购员",
    inputType: "PopoverSelect",
    referName: "CONTACTS_PARAM",
    dataMapping: {
      buyer: "code",
      buyerName: "name",
    },
    require: true,
  },
  {
    key: "buyer",
    title: "采购员编码",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "puDeptName",
    title: "采购部门",
    inputType: "PopoverSelect",
    referName: "DEPT_PARAM",
    dataMapping: {
      puDept: "id",
      puDeptCode: "code",
      puDeptName: "name",
    },
    require: true,
  },
  {
    key: "puDeptCode",
    title: "采购部门编码",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "createByName",
    title: "创建人",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "source",
    title: "来源单据号",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "id",
    title: "来源单据id",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "isEffective",
    title: "是否已推价格",
    inputType: "Select",
    referName: "is_effective",
  },
  {
    key: "effectiveDate",
    title: "生效日期",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "file",
    title: "附件",
    inputType: "Upload",
    span: 24,
    disabled: true,
    readonly: true,
    value: [],
  },
  {
    key: "sourceType",
    title: "来源单据类型",
    inputType: "Input",
    disabled: true,
    readonly: true,
  },
  {
    key: "status",
    title: "单据状态",
    inputType: "Select",
    referName: "sys_status",
    disabled: true,
    readonly: true,
    value: "0",
  },
];

export const TabColumns = [
  {
    title: "物料信息表",
    key: "priceApplyItems",
    tableColumns: [
      {
        title: "物料名称",
        key: "materialName",
        inputType: "PopoverSelect",
        width: 300,
        referName: "MATERIAL_PARAM",
        dataMapping: {
          model: "model",
          material: "id",
          materialCode: "code",
          materialName: "name",
          unitName: "unitIdName",
          puUnitName: "unitIdName",
          specification: "specification",
          manufacturer: "manufacturerId",
          manufacturerName: "manufacturerIdName",
        },
        require: true,
      },
      { title: "物料编码", key: "materialCode" },
      { title: "物料ID", key: "material" },
      {
        title: "生产厂家",
        key: "manufacturerName",
      },
      {
        title: "生产厂家编码",
        key: "manufacturer",
      },
      {
        title: "规格",
        key: "specification",
      },
      {
        title: "型号",
        key: "model",
      },
      {
        title: "单位名称",
        key: "unitName",
        inputType: "PopoverSelect",
        width: 300,
        referName: "UNIT_PARAM",
        dataMapping: {
          unit: "id",
          unitCode: "code",
          unitName: "name",
        },
      },
      {
        title: "单位编码",
        key: "unitCode",
      },
      {
        title: "单位ID",
        key: "unit",
      },
      {
        title: "采购单位名称",
        key: "puUnitName",
        inputType: "PopoverSelect",
        width: 300,
        referName: "UNIT_PARAM",
        dataMapping: {
          puUnit: "id",
          puUnitCode: "code",
          puUnitName: "name",
        },
      },
      {
        title: "采购单位编码",
        key: "puUnitCode",
      },
      {
        title: "采购单位ID",
        key: "puUnit",
      },
      {
        title: "采购换算率",
        key: "conversionRate",
        inputType: "InputNumber",
        width: 300,
        require: true,
      },
      {
        title: "税率%",
        key: "tax",
        inputType: "PopoverSelect",
        referName: "TAX_RATE_PARAM",
        dataMapping: {
          tax: "ntaxrate",
        },
        width: 300,
        require: true,
      },
      {
        title: "含税单价",
        key: "taxPrice",
        inputType: "InputNumber",
        width: 300,
        require: true,
      },
      {
        title: "无税单价",
        key: "price",
        inputType: "ComputedInput",
        width: 300,
        computed: (prop) => {
          const { tax, taxPrice } = prop;
          const newTax = Number(tax) / 100;
          const price = (taxPrice / (1 + newTax)).toFixed(8);
          return price === "NaN" ? null : price;
        },
        require: true,
      },
      {
        key: "currencyName",
        title: "币种名称",
        inputType: "PopoverSelect",
        referName: "CURRENCY_PARAM",
        dataMapping: {
          currency: "id",
          currencyCode: "code",
          currencyName: "name",
        },
      },
      {
        title: "币种编码",
        key: "currencyCode",
      },
      {
        title: "币种ID",
        key: "currency",
      },
      {
        key: "periodBegin",
        title: "价格有效期（起）",
        inputType: "DatePicker",
        valueFormat: "yyyy-MM-dd",
        value: new Date(),
        require: true,
      },
      {
        key: "periodEnd",
        title: "价格有效期（止）",
        inputType: "DatePicker",
        valueFormat: "yyyy-MM-dd",
        pickerOptions: {
          disabledDate(time) {
            return time.getTime() < Date.now() + 3600 * 1000 * 24 * 365;
          },
        },
        value: new Date(new Date().getTime() + 3600 * 1000 * 24 * 366),
        require: true,
      },
      {
        title: "客户",
        key: "customerName",
        inputType: "PopoverSelect",
        width: 300,
        referName: "CUSTOMER_PARAM",
        dataMapping: {
          customer: "id",
          customerCode: "code",
          customerName: "name",
        },
      },
      {
        title: "客户编码",
        key: "customerCode",
      },
      {
        title: "客户ID",
        key: "customer",
      },
      {
        title: "最近价格",
        key: "recentlyPrice",
      },
      {
        title: "首次报批",
        key: "isApprovalFirst",
        width: 300,
        inputType: "Select",
        referName: "is_effective",
      },
      {
        title: "价格调整",
        key: "isPriceAdjustment",
        width: 300,
        inputType: "Select",
        referName: "is_effective",
      },
      {
        key: "priceType",
        title: "价格类型",
        inputType: "Select",
        referName: "sys_price_type",
      },
      {
        title: "配送价",
        key: "isDistributionPrice",
        width: 300,
        inputType: "Select",
        referName: "is_effective",
        require: true,
      },
      {
        title: "创建人名称",
        key: "createByName",
      },
      {
        title: "更新人名称",
        key: "updateByName",
      },
    ],
  },
  {
    title: "合同执行组织范围",
    key: "priceApplyOrgs",
    tableColumns: [
      {
        title: "组织名称",
        key: "orgName",
        inputType: "PopoverSelect",
        referName: "ORG_PARAM",
        dataMapping: {
          org: "id",
          orgCode: "code",
          orgName: "name",
        },
      },
      { title: "组织编码", key: "orgCode" },
      { title: "组织ID", key: "org" },
      {
        title: "创建人名称",
        key: "createByName",
      },
      {
        title: "更新人名称",
        key: "updateByName",
      },
    ],
  },
];

export default { FormColumns, TabColumns };
